Struct prometheus_utils::Observations [−][src]
Collect observations, which are sampled as a Sample.
Implementations
Constructor. The name parameter has no semantic meaning, and is only
exposed by Observations::name().
Name associated with the observations, as provided in constructor.
Take a sample of the observations. Calculates a Sample corresponding to the current
state, and then clears that state.